==> piwigo-2.1.5.zip: piwigo/plugins/LocalFilesEditor/language/sk_SK/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf'] = 'Lokálna konfigurácia';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_tpl'] = 'Šablóny';
$lang['locfiledit_onglet_lang'] = 'Jazyky';
$lang['locfiledit_onglet_plug'] = 'Osobný Plugin';
$lang['locfiledit_cant_save'] = 'Súčasný súbor nie je zapisovateľný. Skontrolujte, či adresár "include/" je zapisovateľný (chmod).';
$lang['locfiledit_newfile'] = 'Súbor neexistuje a bude vytvorený pomocou LocalFiles Editor';
$lang['locfiledit_save_config'] = 'Súbor bol úspešne zapísaný.';
$lang['locfiledit_show_default'] = 'Zobraziť referenčný súbor: ';
$lang['locfiledit_save_bak'] = 'Záložná kópia bude vytvorená pri uložení.';
$lang['locfiledit_saved_bak'] = 'Vytvorený záložný súbor (%s)';
$lang['locfiledit_save_file'] = 'Uložiť súbor';
$lang['locfiledit_choose_file'] = 'Vybrať súbor na editovanie';
$lang['locfiledit_edit'] = 'Editovať';
$lang['locfiledit_restore'] = 'Obnoviť záložný súbor';
$lang['locfiledit_restore_confirm'] = 'Prosím potvrdíte?
Obnova nebude účinná pokiaľ neuložíte.';
$lang['locfiledit_bak_loaded1'] = 'Záložný súbor nahraný.';
$lang['locfiledit_bak_loaded2'] = 'Musíte uložiť súbor na jeho obnovenie.';
$lang['locfiledit_syntax_error'] = 'Syntaktický chyba! Súbor nemôže byť uložený.';
$lang['locfiledit_enable_editarea'] = 'Povoliť editáciu';
$lang['locfiledit_disable_editarea'] = 'Zakázať editáciu';
$lang['locfiledit_new_tpl'] = 'Vytvorenie nového súboru';
$lang['locfiledit_new_filename'] = 'Meno súboru';
$lang['locfiledit_model'] = 'Model';
$lang['locfiledit_empty_page'] = 'Prázdna strana';
$lang['locfiledit_parent_directory'] = 'Domovský adresár';
$lang['locfiledit_filename_error'] = 'Nepovolené znaky v názve súboru.';
$lang['locfiledit_file_already_exists'] = 'Súbor už existuje.';
$lang['locfiledit_model_error'] = 'Musíte vybrať model.';
$lang['locfiledit_empty_filename'] = 'Musíte zadať meno súboru.';
$lang['locfiledit_webmaster_only'] = 'Len webmasteri môžu vytvoriť alebo modifikovať lokálne súbory.';

?>

==> piwigo-2.1.6.zip: piwigo/plugins/LocalFilesEditor/language/sk_SK/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf'] = 'Lokálna konfigurácia';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_tpl'] = 'Šablóny';
$lang['locfiledit_onglet_lang'] = 'Jazyky';
$lang['locfiledit_onglet_plug'] = 'Osobný Plugin';
$lang['locfiledit_cant_save'] = 'Súčasný súbor nie je zapisovateľný. Skontrolujte, či adresár "local/" je zapisovateľný (chmod).';
$lang['locfiledit_newfile'] = 'Súbor neexistuje a bude vytvorený pomocou LocalFiles Editor';
$lang['locfiledit_save_config'] = 'Súbor bol úspešne zapísaný.';
$lang['locfiledit_show_default'] = 'Zobraziť referenčný súbor: ';
$lang['locfiledit_save_bak'] = 'Záložná kópia bude vytvorená pri uložení.';
$lang['locfiledit_saved_bak'] = 'Vytvorený záložný súbor (%s)';
$lang['locfiledit_save_file'] = 'Uložiť súbor';
$lang['locfiledit_choose_file'] = 'Vybrať súbor na editovanie';
$lang['locfiledit_edit'] = 'Editovať';
$lang['locfiledit_restore'] = 'Obnoviť záložný súbor';
$lang['locfiledit_restore_confirm'] = 'Prosím potvrdíte?
Obnova nebude účinná pokiaľ neuložíte.';
$lang['locfiledit_bak_loaded1'] = 'Záložný súbor nahraný.';
$lang['locfiledit_bak_loaded2'] = 'Musíte uložiť súbor na jeho obnovenie.';
$lang['locfiledit_syntax_error'] = 'Syntaktický chyba! Súbor nemôže byť uložený.';
$lang['locfiledit_enable_editarea'] = 'Povoliť editáciu';
$lang['locfiledit_disable_editarea'] = 'Zakázať editáciu';
$lang['locfiledit_new_tpl'] = 'Vytvorenie nového súboru';
$lang['locfiledit_new_filename'] = 'Meno súboru';
$lang['locfiledit_model'] = 'Model';
$lang['locfiledit_empty_page'] = 'Prázdna strana';
$lang['locfiledit_parent_directory'] = 'Domovský adresár';
$lang['locfiledit_filename_error'] = 'Nepovolené znaky v názve súboru.';
$lang['locfiledit_file_already_exists'] = 'Súbor už existuje.';
$lang['locfiledit_model_error'] = 'Musíte vybrať model.';
$lang['locfiledit_empty_filename'] = 'Musíte zadať meno súboru.';
$lang['locfiledit_webmaster_only'] = 'Len webmasteri môžu vytvoriť alebo modifikovať lokálne súbory.';

?>
